Physics Documentation
=====================

The following pages contain white-ups that explain the theoretical basis for the many operations performed by rydiqule.

Equations of Motion Generation
------------------------------

.. toctree::
    :maxdepth: 3
    
    eom_notes

Stacking Conventions
------------------------------

.. toctree::
    :maxdepth: 3
    
    stacking_conventions

Observables
-----------

.. toctree::
    :maxdepth: 3

    observables

Doppler Averaging
-----------------

.. toctree::
    :maxdepth: 3

    doppler

Time-Dependence
---------------

.. toctree::
    :maxdepth: 3

    time_dependence

Solving with Atomic Structure
-----------------------------

.. toctree::
    :maxdepth: 3

    nlj
    sublevels
